/*
Module : DYNDATA.H
Purpose: Defines the interface for a class to access the performance data as stored under the HKEY_DYN_DATA registry 
         key on Windows 9x. Please note that this class is not designed to be used on NT, 2000, XP, 2003, Vista.

Copyright (c) 1999 - 2007 by PJ Naughter (Web: www.naughter.com, Email: pjna@naughter.com)

All rights reserved.

Copyright / Usage Details:

You are allowed to include the source code in any product (commercial, shareware, freeware or otherwise) 
when your product is released in binary form. You are allowed to modify the source code in any way you want 
except you cannot modify the copyright details at the top of each module. If you want to distribute source 
code with your application, then you are only allowed to distribute versions released by the author. This is 
to maintain a single distribution point for the source code. 

*/

/////////////////////////////// Macros / Defines //////////////////////////////

#pragma once

#ifndef __DYNDATA_H__
#define __DYNDATA_H__

#ifndef DYNDATA_EXT_CLASS
#define DYNDATA_EXT_CLASS
#endif


////////////////////////////// Classes ////////////////////////////////////////

//Forward declaration
class CDynDataObject;                      

//Class which represents a single performance object
class DYNDATA_EXT_CLASS CDynDataObject
{
public:
//Constructors / Destructors
  CDynDataObject(LPCTSTR pszObjName, HKEY hObjectKey);
  CDynDataObject(LPCTSTR pszObjName, LPCTSTR pszComputerName);

//Typedefs
  typedef BOOL (*ENUMERATE_DYNDATA_OBJECT_COUNTERS)(DWORD_PTR dwItemData, CDynDataObject& object, const CString& sRegistryName, 
                                                    const CString& sCommonName, const CString& sDescription, BOOL bDifferentiate);
  
//Methods
  BOOL EnumCounters(ENUMERATE_DYNDATA_OBJECT_COUNTERS lpEnumFunc, DWORD_PTR dwItemData = 0);
  CString GetName() const { return m_sName; };
  CString GetDescription() const { return m_sDescription; };

protected:
//Methods
  BOOL _EnumCounters(ENUMERATE_DYNDATA_OBJECT_COUNTERS lpEnumFunc, DWORD_PTR dwItemData, HKEY hObjectKey);

//Data
  CString m_sName;
  CString m_sDescription;
  HKEY    m_hObjectKey;
  CString m_sComputerName;
};

//Class which allows enumeration of a performance objects on a specifed computer
class DYNDATA_EXT_CLASS CDynDataEnumerator
{
public:
//Typedefs
  typedef BOOL (*ENUMERATE_DYNDATA_OBJECTS)(DWORD_PTR dwItemData, CDynDataObject& object);

//Methods
  BOOL EnumObjects(ENUMERATE_DYNDATA_OBJECTS lpEnumFunc, DWORD_PTR dwItemData = 0, LPCTSTR pszComputerName = NULL);
};

//Class which represents a specific usage of a performace counter
class DYNDATA_EXT_CLASS CDynDataCounter
{
public:
//Constructors / Destructors
  CDynDataCounter();
  virtual ~CDynDataCounter();

//Methods
  BOOL Start(LPCTSTR pszObjName, LPCTSTR pszCounterName, LPCTSTR pszComputerName = NULL);
  BOOL Collect(DWORD& dwData);
  BOOL Stop();
  CString GetCounterName() const { return m_sCounterName; };

protected:
//Member variables
  CString m_sCounterName;   
  CString m_sComputerName;
};

#endif //__DYNDATA_H__
